@@ -24,6 +24,7 @@ def print_info():
 def main():
     parser = argparse.ArgumentParser(description=DESCRIPTION)
     parser.add_argument('--command', metavar='command', required=False, type=str, help='the command. Supported commands are: listen (run the webthing service), register (register and starts the webthing service as a systemd unit, deregister (deregisters the systemd unit), log (prints the log)')
+    parser.add_argument('--hostname', metavar='hostname', required=False, type=str, help='the hostname of the webthing serivce')
     parser.add_argument('--port', metavar='port', required=False, type=int, help='the port of the webthing serivce')
     parser.add_argument('--gpio', metavar='gpio', required=False, type=int, help='the gpio number wired to the device')
     parser.add_argument('--name', metavar='name', required=False, type=str, default="", help='the name')
@@ -32,21 +33,25 @@ def main():
     if args.command is None:
         print_info()
     elif args.command == 'listen':
-        if args.port is None:
+        if args.hostname is None:
+            print("--hostname is mandatory")
+        elif args.port is None:
             print("--port is mandatory")
         elif args.gpio is None:
             print("--gpio is mandatory")
         else:
-            print("running " + PACKAGENAME + "/" + args.name + " on port " + str(args.port) + "/gpio " + str(args.gpio))
-            run_server(int(args.port), int(args.gpio), args.name, DESCRIPTION)
+            print("running " + PACKAGENAME + "/" + args.name + " on " + args.hostname + "/" + str(args.port) + "/gpio " + str(args.gpio))
+            run_server(args.hostname, int(args.port), int(args.gpio), args.name, DESCRIPTION)
     elif args.command == 'register':
-        if args.port is None:
+        if args.hostname is None:
+            print("--hostname is mandatory")
+        elif args.port is None:
             print("--port is mandatory")
         elif args.gpio is None:
             print("--gpio is mandatory")
         else:
-            print("register " + PACKAGENAME + "/" + args.name + " on port " + str(args.port) + "/gpio " + str(args.gpio) + " and starting it")
-            register(PACKAGENAME, ENTRY_POINT, int(args.port), args.name, int(args.gpio))
+            print("register " + PACKAGENAME + "/" + args.name  + " on " + args.hostname + "/" + str(args.port) + "/gpio " + str(args.gpio) + " and starting it")
+            register(PACKAGENAME, ENTRY_POINT, args.hostname, int(args.port), args.name, int(args.gpio))
     elif args.command == 'deregister':
         if args.port is None:
             print("--port is mandatory")
